@@ -195,6 +195,14 @@ def sbatch_register_subparser(subparser):
         help="Type of status you want to get notice, default is fail, means only get notice when job failed."
     )
 
+    parser_req.add_argument(
+        "--template",
+        type=str,
+        choices=['yap', 'schicluster'],
+        default='yap',
+        help="Type of sbatch template to use."
+    )
+
     parser.add_argument(
         "--max_jobs",
         type=int,
@@ -623,6 +631,41 @@ def snm3c_imputation_subparser(subparser):
              'and just want to use this command to change settings and update snakefiles.'
     )
     parser.set_defaults(skip_scool_prep=False)
+
+    parser.add_argument(
+        '--blacklist_1d_path',
+        type=str,
+        required=False,
+        default=None,
+        help='Path to blacklist region BED file, such as ENCODE blacklist. '
+             'Either side of the contact overlapping with a blacklist region will be removed.'
+    )
+
+    parser.add_argument(
+        '--blacklist_2d_path',
+        type=str,
+        required=False,
+        default=None,
+        help='Path to blacklist region pair BEDPE file. '
+             'Both side of the contact overlapping with the same '
+             'blacklist region pair will be removed.'
+    )
+
+    parser.add_argument(
+        '--blacklist_resolution',
+        type=int,
+        default=10000,
+        required=False,
+        help='Resolution in bps when consider the 2D blacklist region pairs.'
+    )
+
+    parser.add_argument(
+        '--not_remove_duplicates',
+        dest='remove_duplicates',
+        action='store_false',
+        help='If set, will NOT remove duplicated contacts based on [chr1, pos1, chr2, pos2] values'
+    )
+    parser.set_defaults(remove_duplicates=True)
     return
 
 
